@@ -12,11 +12,11 @@
  *     GNU General Public License for more details.
  * 
  *     You should have received a copy of the GNU General Public License
- *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+ *     along with this program; if not, write to the Free Software Foundation,
+ *     Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301,, USA.
  */ 
 
-/* $Id: rfc2047.c,v 1.2 2000/05/01 09:31:07 roland Exp $ */
+/* $Id: rfc2047.c,v 1.4 2005-10-29 14:48:11 roland Exp $ */
 
 #include <ctype.h>
 #include <string.h>
@@ -149,7 +149,7 @@ static int rfc2047_decode_word (char *d, const char *s, size_t len)
     }
     pp = 0;
   }
-  safe_free ((void **) &p);
+  safe_free (&p);
   if (filter)
   {
     pd = d;
