@@ -15,7 +15,7 @@
  *     along with this program; if not, write to the Free Software Foundation,
  *     Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301,, USA.
  *
- * $Id: vcquery.c,v 1.4 2006-11-12 12:08:21 roland Exp $
+ * $Id: vcquery.c,v 1.5 2007-05-20 12:55:05 roland Exp $
  */
 
 #include <stdio.h>
@@ -47,7 +47,7 @@ int main(int argc, char** argv)
     return 1;
   }
 
-  while (vf_get_next_object(&vfobj)) {
+  do {
     fullname = 0;
     /* First extract name */
     if (vf_get_property(&prop, vfobj, VFGP_FIND, NULL, "FN", NULL))
@@ -85,7 +85,7 @@ int main(int argc, char** argv)
 
     if (fullname)
       free(fullname);
-  }
+  } while (vf_get_next_object(&vfobj));
 
   return 0;
 }
